<?php

namespace UnicaenZimbraTest\Service;

use PHPUnit_Framework_TestCase;
use UnicaenZimbra\Service\DistributionList;
use UnicaenZimbra\Entity\DistributionList as DistributionListEntity;
use UnicaenZimbra\Entity\Account as AccountEntity;

/**
 * @group DistributionList
 */
class DistributionListTest extends PHPUnit_Framework_TestCase
{
    /**
     *
     * @var DistributionList
     */
    protected $service;

    protected $data = array(
        'name' => 'dl-tests-unitaires@pp.unicaen.fr',
        'description' => 'Description',
    );

    protected $listMembers = array(
        'laurent.lecluse@pp.unicaen.fr',
        'laurent.lecluse2@pp.unicaen.fr',
        'david.surville@pp.unicaen.fr',
        'olivier.lemonnier@pp.unicaen.fr',
    );

    protected function setUp()
    {
        \UnicaenZimbraTest\Bootstrap::getServiceManager()->get('zimbra')->connect();
        $this->service = \UnicaenZimbraTest\Bootstrap::getServiceManager()->get('zimbraServiceDistributionList');
    }

    public function testCreate()
    {
        $dl = new DistributionListEntity;
        $dl->setName($this->data['name']);
        $properties = $this->data;
        unset($properties['name']);
        $dl->exchangeArray($properties);

        $res = $this->service->create($dl);

        foreach( $properties as $key => $value ){
            $this->assertEquals($value, $res->$key);
        }

        return $res->getId();
    }

    /**
     * @depends testCreate
     * @param type $id
     */
    public function testExists( $id )
    {
        $this->assertTrue( $this->service->exists($id, 'id') );
    }

    /**
     *
     * @depends testCreate
     */
    public function testGetList( $id )
    {
        $res = $this->service->getList('pp.unicaen.fr', 100);

        $this->assertArrayHasKey($id, $res);
        $this->assertEquals( $this->service->getLastCount(), count($res) );
        $this->assertInstanceOf('\UnicaenZimbra\Entity\DistributionList', $res[$id]);
        $this->assertEquals($id, $res[$id]->getId());
    }

    /**
     * @depends testCreate
     * @return DistributionListEntity
     */
    public function testGet( $id )
    {
        $res = $this->service->get($id, 'id');

        $resByName = $this->service->get( $res->getName() );

        $this->assertInstanceOf('\UnicaenZimbra\Entity\DistributionList', $res);
        $this->assertEquals($id, $resByName->getId());
        $this->assertEquals($res, $resByName);

        foreach( $this->data as $key => $value ){
            if ('name' != $key && 'id' != $key ){
                $this->assertEquals($value, $res->$key);
            }
        }
        return $res;
    }

    /**
     * @depends testGet
     * @param \UnicaenZimbra\Entity\DistributionList $dl
     */
    public function testAddMembers( DistributionListEntity $dl )
    {
        $this->service->addMembers($dl, $this->listMembers[0]);
        $this->service->addMembers($dl, array($this->listMembers[1]) );
        $account1 = new AccountEntity;
        $account1->setName($this->listMembers[2]);
        $account2 = new AccountEntity;
        $account2->setName($this->listMembers[3]);

        $this->service->addMembers($dl, $account1);
        $this->service->addMembers($dl, $account2 );
        return $dl;
    }

    /**
     * @depends testAddMembers
     * @param \UnicaenZimbra\Entity\DistributionList $dl
     */
    public function testGetMembers( DistributionListEntity $dl )
    {
        $members = $this->service->getMembers($dl);
        /* Tri des deux tableaux pour les comparer */
        sort($this->listMembers);
        sort($members);
        $this->assertEquals($this->listMembers, $members);
        return $dl;
    }

    /**
     * @depends testAddMembers
     * @param \UnicaenZimbra\Entity\DistributionList $dl
     */
    public function testRemoveMembers( DistributionListEntity $dl )
    {
        $members = $this->listMembers;
        $account1 = new AccountEntity;
        $account1->setName($this->listMembers[2]);
        $members[2] = $account1;

        $this->service->removeMembers($dl, $this->listMembers);
        return $dl;
    }

    /**
     * @depends testRemoveMembers
     * @param \UnicaenZimbra\Entity\DistributionList $dl
     */
    public function testGetNoMembers( DistributionListEntity $dl )
    {
        $members = $this->service->getMembers($dl);
        $this->assertEmpty($members);
        return $dl;
    }

    /**
     * @depends testGet
     */
    public function testModify(DistributionListEntity $dl )
    {
        $dl->displayName = 'Test DL 3';
        $this->service->modify($dl);
        $res = $this->service->get($this->data['name']);
        $this->assertEquals('Test DL 3', $res->displayName);
    }

    /**
     * 
     * @depends testCreate
     */
    public function testRename( $id )
    {
        $newName = 'dl-tests-unitaires2@pp.unicaen.fr';

        $dl = $this->service->rename($id, $newName);
        $this->assertEquals($newName, $dl->getName());
        return $newName;
    }

    /**
     * @depends testRename
     */
    public function testDelete( $name )
    {
        $dl = $this->service->get( $name );
        $this->assertInstanceOf('\UnicaenZimbra\Service\DistributionList', $this->service->delete( $dl ));
    }
}